@@ -3,11 +3,6 @@ from PyObjCTools.TestSupport import *
 
 from CoreText import *
 
-try:
-    long
-except NameError:
-    long = int
-
 class TestCoreText (TestCase):
     def testConstants(self):
         self.assertEqual(kCTVersionNumber10_5, 0x00020000)
@@ -28,6 +23,18 @@ class TestCoreText (TestCase):
     def testConstants10_8(self):
         self.assertEqual(kCTVersionNumber10_8, 0x00050000)
 
+    @min_os_level('10.9')
+    def testConstants10_9(self):
+        self.assertEqual(kCTVersionNumber10_9, 0x00060000)
+
+    @min_os_level('10.10')
+    def testConstants10_10(self):
+        self.assertEqual(kCTVersionNumber10_10, 0x00070000)
+
+    @min_os_level('10.11')
+    def testConstants10_11(self):
+        self.assertEqual(kCTVersionNumber10_11, 0x00080000)
+
     def testFunctions(self):
         v = CTGetCoreTextVersion()
         self.assertIsInstance(v, (int, long))
